globals "globals.4gl"

function nnakllist_sel(where_str, sort_str)
define  
    where_str   char(256),
    sort_str    char(64),
    p   record
        cod         integer,
        schetcod    integer,
        num         like nnakl.num,
        dat         like nnakl.dat,
        klientnam   like klient.nam,
        summa       decimal(9,2),
        summands    decimal(9,2)
    end record,
    str         char(1024)
    
    whenever error call err

    let str = "select a.cod, b.cod, a.num as num, a.dat as dat, c.nam as knam, ",
                     "a.summa as summa, a.summands ",
                 "from _nnaklsnds a, schetfnr b, klient c ",
                 "where a.schetfnr_cod = b.cod and ",
                       "b.klient_cod = c.cod and ",
                       where_str clipped," ",
                 "order by ", sort_str clipped
    prepare p_sel from str
    
    initialize p to null
    declare cur_sel cursor for p_sel
    let transaction = 1    
    begin work
    foreach cur_sel into p.*
        if p.summa is null then let p.summa = 0 end if
        if p.summands is null then let p.summands = 0 end if
        display p.cod, "\t", 
                p.schetcod, "\t",
                p.num using "#####", "\t", 
                p.dat using "dd.mm.yyyy", "\t", 
                p.klientnam, "\t", 
                p.summa using "#######.##", "\t",
                p.summands using "#######.##"
    end foreach
    commit work
end function

function nnakllist_rep(where_str, sort_str, pipe_str)
define  
    where_str   char(256),
    sort_str    char(64),
    p   record
        cod         integer,
        schetcod    integer,
        num         like nnakl.num,
        dat         like nnakl.dat,
        klientnam   like klient.nam,
        summa       decimal(9,2)
    end record,
    str         char(1024),
    pipe_str    char(256)
    
    let str = "select a.cod, b.cod, a.num as num, a.dat as dat, c.nam as knam, ",
                     "a.summa as summa ",
                 "from _nnakls a, schetfnr b, klient c ",
                 "where a.schetfnr_cod = b.cod and ",
                       "b.klient_cod = c.cod and ",
                       where_str clipped," ",
                 "order by ", sort_str clipped
    prepare p_replist from str
    
    initialize p to null
    let reppipe = pipe_str
    declare cur_replist cursor for p_replist
    let transaction = 1    
    begin work
    start report r_nnakllist
        foreach cur_replist into p.*
            output to report r_nnakllist( p.num, p.dat, p.klientnam, p.summa)
        end foreach
    finish report r_nnakllist
    commit work
end function

report r_nnakllist(num, dat, klientnam, summa)
define	
    num         like nnakl.num,
    dat         like nnakl.dat,
    klientnam   like klient.nam,
    summa       decimal(9,2)

output
    report to pipe reppipe
    left margin		0
    right margin 	75
    top margin		0
    bottom margin	0
    page length		16
	
format	
    first page header
      print twicewidthon,vidon,"  ",vidoff,twicewidthoff
      print "====================================================================="
      print "   |      |                              |  " 
      print "---------------------------------------------------------------------"
    on every row
      print num, " ", dat, passon, klientnam, " ", passoff, summa using "#######.##"
    on last row
      print "====================================================================="
      print "                            : ",sum(summa) using "#######.##"
      print "====================================================================="
      call whatsot()
      print downindex,": ",userfio clipped,indexoff,formfeed
end report

function nnakl_del(nnaklcod)
define
    str                 char(128),
    nnaklcod     integer
    
    let str = "execute procedure nnakl_del(?)"
    prepare p_del from str
    let transaction = 1
    begin work
    execute p_del using nnaklcod
    commit work
end function

function nnakl_sel(nnaklcod)
define  
    nnaklcod   integer,
    p   record
        klientcod   integer,
        num         like nnakl.num,
        dat         like nnakl.dat,
        klientnam   like klient.nam,
        umova       like nnakl.umova,
        forma       like nnakl.forma,
        prim1       like nnakl.prim1
    end record
    
    initialize p to null
    let transaction = 1    
    begin work
    select  c.cod, a.num, a.dat, c.nam, a.umova, a.forma, a.prim1
        into p.*
        from nnakl a, schetfnr b, klient c
        where a.cod = nnaklcod and
              a.schetfnr_cod = b.cod and
              b.klient_cod = c.cod
    commit work
    
    display p.klientcod, "\t",
            p.num using "#####", "\t",
            p.dat using "dd.mm.yyyy", "\t",
            p.klientnam, "\t",
            p.umova, "\t",
            p.forma, "\t",
            p.prim1
end function
    
function nnaklgenerate(schetcod, sofnrcod, st)
define
    schetcod, sofnrcod  integer,
    st              char(8),
	schetnum        char(5),
	schetdat        char(10),
	umova           char(60),
	forma           char(60),
	nnaklnum        smallint,
	nnakldat        date,
	nnaklcod        integer,
	schfnrtovcod    integer,
	stschet         decimal(9,2),
	stnnakl         decimal(9,2),
	sumtov          decimal(9,2),
	schetopls       decimal(9,2),
	schets, nnakls, nnaklcurrents, ss, pop  decimal(9,2),
	operaciacod     integer,
	cnt             smallint
    
    let st = st clipped
    let transaction = 1
    begin work
    select schet_num, schet_dat, operacia_cod
        into schetnum, schetdat, operaciacod
	    from schetfnr
	    where cod = schetcod
	let umova = " N-",schetnum clipped,"  ",schetdat," "
	
    select count(*) into cnt
        from operacia
        where p_r = -1 and 
              nam matches "**" and
              cod = operaciacod

    if cnt > 0
	then
	    let forma = " "
	else
	    let forma = "   "
	end if

	if st = "finnaklr" then
	    select finnaklr_dat into nnakldat 
	        from schetfnr 
	        where cod = schetcod
	end if
	if st = "schetopl" then
	    select dat, summa into nnakldat, schetopls
	        from schetopl 
	        where cod = sofnrcod
	end if

	select max(num) + 1 into nnaklnum
	    from nnakl
	    where year(dat) = year(nnakldat)
	if nnaklnum is null then let nnaklnum = 1 end if

	insert into nnakl values(0, schetcod, sofnrcod, nnaklnum, nnakldat, umova, forma, '',user)
	let nnaklcod = sqlca.sqlerrd[2]
	declare cur_gen1 cursor for
        select schfnrtov_cod, st_schet, st_nnakl
            from _schetnnakltovs
            where schet_cod = schetcod

	if st = "finnaklr" then
        foreach cur_gen1 into schfnrtovcod, stschet, stnnakl
            if stnnakl is null then let stnnakl = 0  end if
            let sumtov = stschet - stnnakl
            if sumtov > 0 then
                insert into nnakltov values(0, nnaklcod, schfnrtovcod, sumtov, user)
            end if
        end foreach
	end if
	if st = "schetopl" then
	    select summa into schets
	        from _schets
	        where cod = schetcod
	        
	    select summa into nnakls
	        from _schetnnakls
	        where schet_cod = schetcod
	    if nnakls is null then let nnakls = 0 end if
	    
	    let nnaklcurrents = schets - nnakls
	    
	    #     
	    if nnaklcurrents = schetopls then
	        foreach cur_gen1 into schfnrtovcod, stschet, stnnakl
                if stnnakl is null then let stnnakl = 0  end if
                let sumtov = stschet - stnnakl
                if sumtov > 0 then
                    insert into nnakltov values(0, nnaklcod, schfnrtovcod, sumtov, user)
                end if
            end foreach
        end if
        
        #     
        if nnaklcurrents > schetopls then
	        let ss = 0
	        foreach cur_gen1 into schfnrtovcod, stschet, stnnakl
                let sumtov = schetopls * stschet / schets
                let ss = ss + sumtov
                let pop = schetopls - ss
                if pop = 0.01 or pop = -0.01 then
                    let sumtov = sumtov + pop
                end if
                if sumtov > 0 then
                    insert into nnakltov values(0, nnaklcod, schfnrtovcod, sumtov, user)
                end if
            end foreach
        end if
	end if
    commit work
end function

function nnakl_upd(nnaklcod, num, dat, umova, forma, prim1)
define
    str     	char(128),
    nnaklcod    integer,
    num         like nnakl.num,
    dat         like nnakl.dat,
    umova       like nnakl.umova,
    forma       like nnakl.forma,
    prim1       like nnakl.prim1
    
    let str = "execute procedure nnakl_upd(?,?,?,?,?,?)"
    prepare p_upd from str
    let transaction = 1
    begin work
    let umova = umova clipped
    let forma = forma clipped
    let prim1 = prim1 clipped
    execute p_upd using nnaklcod, num, dat, umova, forma, prim1
    commit work
end function

function nnakl_rep(schetcod, nnaklcod, order_str, pipe_str)
define	schetcod, nnaklcod	integer,
    order_str   char(64),
    pipe_str    char(256),
	nnaklnum	like nnakl.num,
	nnakldat	like nnakl.dat,
	klientnam	like klient.nam,
	klientinn	like klient.inn,
	klientgorod	like gorod.nam,
	klientulica	like klient.ulica,
	klientphoneo	like klient.phone_o,
	klientns	like klient.ns,
	umovaa		like nnakl.umova,
	formaa		like nnakl.forma,
	i, ret, flg_rep	smallint,
	cenawithoutpdv, pdv, cena, cenaforwpdv	decimal(20,10),
	isurlico	like klient.urlico,
	isnds		like klient.nds,
	p record
	    printnam    like schfnrtov.printnam,
	    kol         like schfnrtov.kol,
	    summa       like nnakltov.summa,
	    einam       like ei.nam,
	    isnds       like tovar.isnds
	end record
	
	let reppipe = pipe_str
	initialize p to null
	
	select num, dat, umova, forma
	    into nnaklnum, nnakldat, umovaa, formaa
	    from nnakl
	    where cod = nnaklcod
	
	select b.nam, b.inn, c.nam, b.ulica, b.phone_o, b.ns, b.urlico, b.nds
	  into klientnam, klientinn, klientgorod, klientulica, klientphoneo, 
	       klientns, isurlico, isnds
	  from schetfnr a, klient b, gorod c
	  where a.cod = schetcod and
	  	    a.klient_cod = b.cod and
	  	    b.gorod_cod = c.cod
	
	if isurlico is null or (isurlico is not null and isnds is null) 
	then 
	  let isurlico = '*'
	  let isnds = '*'
	  let klientinn = "XXXXXXXXXXXX"
	  let klientns = "XXXXXXXX"
	end if 
	if isurlico = '*' and
	   isnds = '*' and 
	   klientinn is not null and
	   klientns is not null 
	then
	  declare cur_rep cursor for
	    select b.printnam as pnam, b.kol as koll, a.summa as cenaa,
	           d.nam as enam, c.isnds, c.nam as tnam 
	        from nnakltov a, schfnrtov b, tovar c, ei d
	        where a.nnakl_cod = nnaklcod and
	              a.schfnrtov_cod = b.cod and
	              b.tovar_cod = c.cod and
	              c.ei_cod = d.cod
	  start report r_nnakl
	    foreach cur_rep into p.*
	      let cena = p.summa / p.kol
	      if p.isnds is not null then
	        call funpdv(nnakldat, cena) returning cenawithoutpdv, pdv
	        let cenaforwpdv = 0
	      else
	        let cenaforwpdv = cena
	        let cena = 0
	        let cenawithoutpdv = 0
	        let pdv = 0
	      end if
	      output to report r_nnakl(nnaklnum, 
	    			       nnakldat, 
	    			       klientnam,
	    			       klientinn,
	    			       klientgorod,
	    			       klientulica,
	    			       klientphoneo,
	    			       klientns,
	    			       umovaa,
	    			       formaa,
	    			       p.printnam,
	    			       p.kol,
	    			       p.einam,
	    			       cenawithoutpdv,
	    			       pdv,
	    			       cena,
	    			       cenaforwpdv,
	    			       p.isnds
	    			     )
	    end foreach
	  finish report r_nnakl
	else
	  display "errklientnds"
	end if
end function

report r_nnakl( nnaklnum, nnakldat, klientnam, klientinn, klientgorod,
		klientulica, klientphoneo, klientns, umova, forma,
		tovarnam, kol, einam, cenawithoutpdv, pdv, cena, cenaforwpdv, ispdv
	      ) 
define	
    nnaklnum	like nnakl.num,
    nnakldat	like nnakl.dat,
    klientnam	like klient.nam,
    klientinn	like klient.inn,
    klientgorod	like gorod.nam,
    klientulica	like klient.ulica,
    klientphoneo	like klient.phone_o,
    klientns	like klient.ns,
    umova	like nnakl.umova,
    forma	like nnakl.forma,
    tovarnam	like tovar.nam,
    kol		like schfnrtov.kol,
    einam	like ei.nam,
    cenawithoutpdv, pdv, cena, cenaforwpdv	decimal(20,10),
    ispdv	like tovar.isnds
	
output
    report to pipe reppipe
    left margin		0
    right margin 	75
    top margin		0
    bottom margin	0
    page length		84
	
format	
    first page header
      call myorg()
      print passon, betweenstr8
      print "i ( )     |     |                                                      i"
      print underlineon," i ( ) |     |",underlineoff,"                                                i 30.05.97  N-165"
      print "  ( i i i '' )"
      print ""
      print passoff,twicewidthon,vidon,"      ",vidoff,twicewidthoff,passon
      print ""
      print "  i i",passoff,vidon,nnakldat using "dd/mm/yyyy",vidoff,passon,"                      ",passoff,vidon,nnaklnum using "<<<<<",vidoff,passon
      print ""
      print passoff,vidon,"                                      ",vidoff,passon
      print "             .---------------------------.                           .---------------------------"
      print "(-) | ",p_myorg.nam[1,25]," |              ( ) | ",klientnam[1,25]," |"
      print "         | ",p_myorg.nam[26,50]," |                        | ",klientnam[26,50]," |"
      print "                  `---------------------------'                                `---------------------------"
      print "                     (; i, i',                                      (; i, i',"
      print "                 -i- ii )                             -i- ii )"
      print ""
      print "    .-----------------------------------------------.                 .-----------------------------------------------."
      print "    | ",p_myorg.inn[1],"   ",p_myorg.inn[2],"   ",p_myorg.inn[3],"   ",p_myorg.inn[4],"   ",p_myorg.inn[5],"   ",p_myorg.inn[6],"   ",p_myorg.inn[7],"   ",p_myorg.inn[8],"   ",p_myorg.inn[9],"   ",p_myorg.inn[10],"   ",p_myorg.inn[11],"   ",p_myorg.inn[12]," |";
      print column 67,"    | ",klientinn[1],"   ",klientinn[2],"   ",klientinn[3],"   ",klientinn[4],"   ",klientinn[5],"   ",klientinn[6],"   ",klientinn[7],"   ",klientinn[8],"   ",klientinn[9],"   ",klientinn[10],"   ",klientinn[11],"   ",klientinn[12]," |"
      print "    `-----------------------------------------------'                 `-----------------------------------------------'"
      print "       (Ii   )                         (Ii   )"
      print ""
      print "i                                                    i "
      print ": ",p_myorg.gorod_nam clipped," ",p_myorg.ulica clipped, column 69," ",klientgorod clipped," ",klientulica clipped
      print " : ",p_myorg.phone_o, column 69,"  ",klientphoneo clipped
      print ""
      print "     i       .----------------------.                i        .-----------------------."
      print "i    |   ",p_myorg.ns[1]," ",p_myorg.ns[2]," ",p_myorg.ns[3]," ",p_myorg.ns[4]," ",p_myorg.ns[5]," ",p_myorg.ns[6]," ",p_myorg.ns[7]," ",p_myorg.ns[8],"    |";
      print "            i    |    ",klientns[1]," ",klientns[2]," ",klientns[3]," ",klientns[4]," ",klientns[5]," ",klientns[6]," ",klientns[7]," ",klientns[8],"    |"
      print "  i() `----------------------'              i()  `-----------------------'"
      print ""
      print "    : ",underlineon,umova,underlineoff
      print "                        ( i- )"
      print "     i: ",underlineon,forma,underlineoff
      print "                                  (, i,   /.,  )"
      print ".---------------------------------------------------------------------------------------------------------------------------."
      print "|   |      |                                   |      |       |         |                                |         |"
      print "||i-|               | - |i-  |  i   |    ( )    | |"
      print "|i|   ,  |       i(i, )      |  |i, |  |     ,  i    |     |"
      print "|   |,|                           |i|(',| i |              | i, |"
      print "|   | , |                                   ||) |-  |-------------------------------------|       |"
      print "|   |    |                                   |      |       |i   |         |0% (-|        | i-  |i |"
      print "|   | i, |                                   |      |       | -  |         | ii|   0%   |    | i  |"
      print "|   |  i,  |                                   |      |       |    |   20%   | - | | i  |         |"
      print "|   |    |                                   |      |       |      |         |i - |        | (.5)  |         |"
      print "|   |          |                                   |      |       |         |         | i|        |         |         |"
      print "|   |          |                                   |      |       |         |         | |        |         |         |"
      print "|---|----------|-----------------------------------|------|-------|---------|---------|--------|--------|---------|---------|"
      print "| 1 |     2    |                3                  |  4   |   5   |    6    |    7    |    8   |    9   |   10    |   11    |"
      print "|---|----------|-----------------------------------|------|-------|---------|---------|--------|--------|---------|---------|"
    on every row
      if lineno = 49 then
        if ispdv = '*' then
          print "|  I|",nnakldat using "dd/mm/yyyy|",tovarnam[1,35],"|",einam[1,6],"|",kol using "####.##|",cenawithoutpdv using "######.##|",kol * cenawithoutpdv using "######.##|","        |        |         |         |"
        else
          print "|  I|",nnakldat using "dd/mm/yyyy|",tovarnam[1,35],"|",einam[1,6],"|",kol using "####.##|",cenaforwpdv using "######.##|","         |        |        |",cenaforwpdv * kol using "######.##|","         |"
        end if
      else
        if ispdv = '*' then
          print "|  I|",nnakldat using "dd/mm/yyyy|",tovarnam[1,35],"|",einam[1,6],"|",kol using "####.##|",cenawithoutpdv using "######.##|",kol * cenawithoutpdv using "######.##|","        |        |         |         |"
        else
          print "|  I|",nnakldat using "dd/mm/yyyy|",tovarnam[1,35],"|",einam[1,6],"|",kol using "####.##|",cenaforwpdv using "######.##|","         |        |        |",cenaforwpdv * kol using "######.##|","         |"
        end if
      end if
    on last row
      print "|   |   i I                          |      |       |         |",sum(cenawithoutpdv * kol) using "######.##|","        |        |",sum(cenaforwpdv * kol) using "######.##|","         |"
      print "| II| -i                   |      |       |         |         |        |        |         |         |"
      print "|III|  ()                      |  X   |   X   |   X     |    X    |    X   |    X   |    X    |    X    |"
      print "| IV|    |   (+)                     |      |       |         |         |        |        |         |         |"
      print "|   |   |   (-)                       |      |       |         |         |        |        |         |         |"
      print "|  V|    i I+II+-IV                 |      |       |         |",sum(cenawithoutpdv * kol) using "######.##|","        |        |",sum(cenaforwpdv * kol) using "######.##|",sum(cenawithoutpdv * kol) + sum(cenaforwpdv * kol) using "######.##|"
      print "| VI|    i                   |      |       |         |",sum(pdv * kol) using "######.##|","        |        |","      .00|",sum(pdv * kol) using "######.##|"
      print "|VII|                              |      |       |         |",sum(cena * kol) using "######.##|","        |        |",sum(cenaforwpdv * kol) using "######.##|",sum(cena * kol) + sum(cenaforwpdv * kol) using "######.##|"
      print "`---------------------------------------------------------------------------------------------------------------------------'"
      print " , i (i)  '   i (i, ),   i i, i i"
      print " ii i  '  i i   i ",passoff
      print ""
      print "     .----------------."
      print "     |      . .     |"
      print "     `----------------'"
      print ""
      print vidon,underlineon,p_myorg.glbuh_fio,underlineoff,vidoff
      print passon,"         (i i i ,   )",passoff
      print "",betweenstr6
      call whatsot()
      print downindex,": ",userfio clipped,indexoff,formfeed
end report
