globals "globals.4gl"

function schetone_sel(schetcod)
define  
    schetcod   integer,
    p   record
        num         like schetfnr.schet_num,
        dat         like schetfnr.schet_dat,
        operaciacod integer,
        operacianam like operacia.nam,
        klientcod   integer,
        klientnam   like klient.nam,
        lgotacod    integer,
        lgotanam    like lgota.nam,
        proc        like lgota.proc,
        lgotaproc   like schetfnr.lgota_proc,
        prim1       like schetfnr.prim1,
        prim2       like schetfnr.prim2,
        datdolga    date
    end record
    
    whenever error call err

    initialize p to null
    let transaction = 1    
    begin work
    select  a.num, a.dat, b.cod, b.nam, c.cod, c.nam,
            d.cod, d.nam, d.proc, a.lgota_proc,
            a.prim1, a.prim2, a.dat_dolga
        into p.*
        from _schet a, operacia b, klient c, outer lgota d
        where a.cod = schetcod and
              a.operacia_cod = b.cod and
              a.klient_cod = c.cod and
              c.lgota_cod = d.cod
    commit work
    
    display p.num using "#####", "\t",
        p.dat using "dd.mm.yyyy", "\t",
        p.operaciacod, "\t",
        p.operacianam, "\t",
        p.klientcod, "\t",
        p.klientnam, "\t",
        p.lgotacod, "\t",
        p.lgotanam, "\t",
        p.proc using "###.##", "\t",
        p.lgotaproc using "---.--", "\t",
        p.prim1, "\t",
        p.prim2, "\t",
        p.datdolga using "dd.mm.yyyy"
end function
    
function schet_ins(datt, operaciacod, klientcod, lgotaproc, prim1, prim2, datdolga)
define
    str     	char(128),
    schetnum         like schetfnr.schet_num,
    datt        like schetfnr.schet_dat,
    schetcod, operaciacod, klientcod   integer,
    lgotaproc   like schetfnr.lgota_proc,
    prim1       like schetfnr.prim1,
    prim2       like schetfnr.prim2,
    datdolga    date
    
    initialize schetcod, schetnum to null
    let str = "execute procedure schet_ins(?,?,?,?,?,?,?)"
    prepare p_ins from str
    declare cur_ins cursor for p_ins
    let transaction = 1
    begin work
    open cur_ins using datt, operaciacod, klientcod, lgotaproc, prim1, prim2, datdolga
        fetch cur_ins into schetcod, schetnum
        display schetcod, "\t", schetnum using "#####"
    close cur_ins
    commit work
end function

function schet_upd(schetcod, schetnum, datt, operaciacod, klientcod, lgotaproc, prim1, prim2, datdolga)
define
    str     	char(128),
    schetnum         like schetfnr.schet_num,
    datt        like schetfnr.schet_dat,
    schetcod, operaciacod, klientcod   integer,
    lgotaproc   like schetfnr.lgota_proc,
    prim1       like schetfnr.prim1,
    prim2       like schetfnr.prim2,
    datdolga    date
    
    let str = "execute procedure schet_upd(?,?,?,?,?,?,?,?,?)"
    prepare p_upd from str
    let transaction = 1
    begin work
    let prim1 = prim1 clipped
    let prim2 = prim2 clipped
    execute p_upd using schetcod, schetnum, datt, operaciacod, klientcod,
                        lgotaproc, prim1, prim2, datdolga
    commit work
end function

function schet_del(schetcod)
define
    str     	char(128),
    schetcod    integer
    
    let str = "execute procedure schet_del(?)"
    prepare p_del from str
    let transaction = 1
    begin work
    execute p_del using schetcod
    commit work
end function

function schet_rep(schetcod, order_str, pipe_str)
define  
    schetcod    integer,
    order_str, pipe_str    char(256),
    str         char(768),
    p   record
        num		    like schetfnr.schet_num,
        dat		    date,
        klientnam	like klient.nam,
        tovarnam	like schfnrtov.printnam,
        isnds       like tovar.isnds,
        kol		    like schfnrtov.kol,
        einam		like ei.nam,
        cena		like schfnrtov.cena,
        lgotanam	like lgota.nam,
        lgotaproc	like schetfnr.lgota_proc
    end record,
    cenawithoutpdv decimal(13,6),
    pdv         decimal(13,6)
        
    let str = "select a.schet_num, a.schet_dat, b.nam, c.printnam as pnam, d.isnds, ",
                     "c.kol as kol, e.nam as enam, c.cena as cena, f.nam, a.lgota_proc, d.nam as tnam ",
                  "from schetfnr a, klient b, schfnrtov c, tovar d, ei e, outer lgota f ",
                  "where a.cod = ",schetcod," and ",
                        "a.klient_cod = b.cod and ",
                        "a.cod = c.schetfnr_cod and ",
                        "c.tovar_cod = d.cod and ",
                        "d.ei_cod = e.cod and ",
                        "b.lgota_cod = f.cod ",
                  " order by ", order_str clipped
    prepare p_repschet from str
    
    initialize p to null
    let reppipe = pipe_str clipped
    declare cur_repschet cursor for p_repschet
    let transaction = 1    
    begin work
    start report r_schet
        foreach cur_repschet into p.*
            if p.isnds = "*" then
                call funpdv(p.dat, p.cena) returning cenawithoutpdv, pdv
            else
                let cenawithoutpdv = p.cena
                let pdv = 0
            end if
            output to report r_schet(p.num, p.dat, p.klientnam, p.tovarnam, 
                                    p.kol, p.einam, cenawithoutpdv, pdv, 
                                    p.cena, p.lgotanam, p.lgotaproc)
        end foreach
    finish report r_schet
    commit work
end function

report r_schet(
	       num, dat, klientnam, tovarnam, kol, einam, cenawithoutpdv, pdv, 
	       cena, lgotanam, lgotaproc
	      )
define	
    num		    like schetfnr.schet_num,
    dat		    date,
    klientnam	like klient.nam,
    tovarnam	like schfnrtov.printnam,
    kol		    like schfnrtov.kol,
    einam		like ei.nam,
    cena		like schfnrtov.cena,
    cenawithoutpdv, pdv decimal(13,6),
    lgotanam	like lgota.nam,
    lgotaproc	like schetfnr.lgota_proc

output
    report to pipe reppipe
    left margin		0
    right margin 	75
    top margin		0
    bottom margin	0
    page length		18
	
format	
    first page header
      skip 10 line
      print twicewidthon,vidon,"          ",vidoff,twicewidthoff,"N-",vidon,num using "<<<<<",vidoff,"i",vidon,dat using "dd/mm/yyyy",vidoff,"."
      print "        :",vidon,klientnam,vidoff
      if lgotanam is not null then
        print passon,"      i :",passoff,vidon,lgotanam clipped,vidoff," ";
      else 
        print " ";
      end if
      if lgotaproc != 0 then
        print passon,"i :",passoff,vidon,lgotaproc using "###.##",vidoff,"%"
      else
        print " "
      end if
      print "==================================================================================="
      print "                             | i- |  i   |     |  " 
      print "                                               | i |   |        |   "
      print "==================================================================================="
    on every row
      print passon,tovarnam,passoff,kol using "####.##",cenawithoutpdv using "  #####.##",pdv using " #####.##",cena * kol using " #####.##"
    on last row
      print "==================================================================================="
      print "                                                              :", sum(cenawithoutpdv * kol) using "######.##"
      print "     (!).                                  :", sum(pdv * kol) using "######.##"
      call myorg()
      print "  i  : ",p_myorg.phone_o,"                       :", sum(cena * kol) using "######.##"
      call whatsot()
      print downindex, ": ", userfio clipped, indexoff
      print topindex, underlineon, " \"-\". Copyright (c) Eduard E. Zozulya doro@doro.poltava.ua", underlineoff, indexoff, formfeed
end report

function schetkwit_rep(schetcod, pipe_str)
define	
    pipe_str    char(256),
    schetcod, klientcod	integer,
	num	        like schetfnr.schet_num,
	klientnam	like klient.nam,
	swpdv	    decimal(20,10),
	pdv	        decimal(20,10),
	sschet, sschetall	    like schfnrtov.cena,
	gorodnam    like gorod.nam,
	ulica       like klient.ulica,
	dom         like klient.dom,
	kv          like klient.kv,
	adr         char(80),
	dovwhoo     like schetfnr.dovwho
	
	let reppipe = pipe_str
	
	initialize num, sschet, adr, klientnam, ulica, dom, kv, gorodnam to null
	let transaction = 1
	begin work
	
	call myorg()
	
	select klient_cod, schet_num, dovwho
	    into klientcod, num, dovwhoo
	    from schetfnr
	    where cod = schetcod
	
	select sum(a.kol * a.cenawpdv), sum(a.kol * a.pdv), sum(a.kol * a.cena)
	    into swpdv, pdv, sschet
	    from _schfnrtovfinccc a
	    where a.schetfnr_cod = schetcod
	  
	select a.nam, b.nam , a.ulica, a.dom, a.kv 
	    into klientnam, gorodnam, ulica, dom, kv
	    from klient a, gorod b
	    where a.cod = klientcod and
	          a.gorod_cod = b.cod
	
	commit work
	
	#let sschetall = sschet + sschet * 0.008
	let sschetall = sschet
	let adr = "; ",gorodnam clipped," ", ulica clipped, ", ", dom clipped,"/", kv clipped
	start report r_kwit
	  output to report r_kwit(num, klientnam, swpdv, pdv, sschetall, adr, dovwhoo)
	finish report r_kwit
end function

report r_kwit(num, klientnam, swpdv, pdv, sschetall, adr, dovwhoo)
define	
    num		    like schetfnr.schet_num,
    klientnam	like klient.nam,
    swpdv	    decimal(20,10),
    pdv	        decimal(20,10),
    sschetall	like schfnrtov.cena,
    adr         char(80),
    dovwhoo     like schetfnr.dovwho


output
    report to pipe reppipe
    left margin		0
    right margin 	75
    top margin		0
    bottom margin	0
    page length		45
	
format	
    on every row
      print betweenstr8,"                                                            N -5"
      print "              : ", day(today) using "## ", speakmonth(month(today)) clipped, year(today) using " #### ", ""
      print "              |                                            .----------."
      print "              |",passon,p_myorg.nam,passoff,"   | ",p_myorg.zkpo," |"
      print "              |                            `----------'"
      print " I |  : ",passon,p_myorg.bank_nam clipped,"  ",p_myorg.bank_mfo,passoff
      print "              |              .------------.              .------------."
      print "              |       | ",passon,p_myorg.bank_schet1,passoff,"|      | ",passon,p_myorg.bank_schet2,passoff,"|"
      print "              |    `------------'       `------------'"
      print "              |", passon, underlineon, klientnam clipped, adr clipped, "; ", dovwhoo clipped, underlineoff,passoff
      print "              |    ",topindex,"i, i', -i, , i ",indexoff
      print "              |--------------------------------------------------------"
      print "              |    |            |       |    |"
      print "              |--------------------------------------------------------"
      print "              |    N-",vidon,num using "<<<<<",vidoff, pdv using "      #######.##", sschetall using " #######.##"
      print "              |--------------------------------------------------------"
      print "              |",passon, underlineon, speak(sschetall using "#########.##",1) clipped,underlineoff, "   i  ", passoff
      print "         |        ",topindex," ",indexoff
      print "              |  ",underlineon,"          ",underlineoff
      print "              |"
      print "--------------|--------------------------------------------------------"
      print "              : ", day(today) using "## ", speakmonth(month(today)) clipped, year(today) using " #### ", ""
      print "              |                                            .----------."
      print "              |",passon,p_myorg.nam,passoff,"   | ",p_myorg.zkpo," |"
      print "              |                            `----------'"
      print " I |  : ",passon,p_myorg.bank_nam clipped,"  ",p_myorg.bank_mfo,passoff
      print "              |              .------------.              .------------."
      print "              |       | ",passon,p_myorg.bank_schet1,passoff,"|      | ",passon,p_myorg.bank_schet2,passoff,"|"
      print "              |    `------------'       `------------'"
      print "              |", passon, underlineon, klientnam clipped, adr clipped, "; ", dovwhoo clipped, underlineoff,passoff
      print "              |    ",topindex,"i, i', -i, , i ",indexoff
      print "              |--------------------------------------------------------"
      print "              |    |            |       |    |"
      print "              |--------------------------------------------------------"
      print "              |    N-",vidon,num using "<<<<<",vidoff, pdv using "      #######.##", sschetall using " #######.##"
      print "  I   |--------------------------------------------------------"
      print "              |",passon,underlineon,speak(sschetall using "#########.##",1) clipped,underlineoff,"   i  ", passoff
      print "         |        ",topindex," ",indexoff
      print "              |  ",underlineon,"          ",underlineoff
      print "              |"
      print "--------------|--------------------------------------------------------"
      call whatsot()
      print betweenstr6,downindex,": ",userfio clipped,indexoff,formfeed
end report

function schetobjava_rep(flg, schetcod, pipe_str)
define	
    pipe_str    char(256),
    schetcod, klientcod	integer,
	num	        like schetfnr.schet_num,
	schetdat    date,
	klientnam	like klient.nam,
	spdv	    like schfnrtov.cena,
	sschet, sschetall, sproc	    like schfnrtov.cena,
	flg         char(1)
	
	let reppipe = pipe_str
	
	let transaction = 1
	begin work
	
	call myorg()
	
	select klient_cod 
	    into klientcod
	    from schetfnr
	    where cod = schetcod
	
	select schet_num, schet_dat
	    into num, schetdat
	    from schetfnr
	    where cod = schetcod
	
	select sum(a.kol * a.pdv), sum(a.kol * a.cena)
	    into spdv, sschet
	    from _schfnrtovfinccc a
	    where a.schetfnr_cod = schetcod

	if flg = 'y' then
	    let sproc = sschet * 0.008
	else
	    let sproc = 0
	end if
	let sschetall = sschet + sproc
	
	select a.nam 
	    into klientnam
	    from klient a
	    where a.cod = klientcod
	
	commit work
	
	start report r_objava
	  output to report r_objava(flg, num, schetdat, klientnam, spdv, sschetall, sschet, sproc)
	finish report r_objava
end function

report r_objava(flg, num, schetdat, klientnam, spdv, sschetall, sschet, sproc)
define	
    num		    like schetfnr.schet_num,
    schetdat    date,
    klientnam	like klient.nam,
    spdv	    like schfnrtov.cena,
    sschetall, sschet, sproc	    like schfnrtov.cena,
    strspeak    char(80),
    flg         char(1)


output
    report to pipe reppipe
    left margin		0
    right margin 	75
    top margin		0
    bottom margin	0
    page length		45
	
format	
    on every row
      let strspeak = speak(sschetall using "#########.##",1)
      let strspeak[2] = toupper(strspeak[2])
      print betweenstr8
      print "                                    .-------. .---------."
      print "                     ' N -     |       | | 0402001 |"
      print "                  i `-------' `---------'"
      #print "             ______________________ 200__ . "
      print "                 :", day(today) using "## ", speakmonth(month(today)) clipped, year(today) using " #### ", ""
      print "                                                         .----------------."
      print "                                                         | 29027304440000 |"
      print "                                             . |----------------|"
      print "i : ", passon, underlineon, klientnam, " ", underlineoff, passoff, "       N |",vidon, p_myorg.bank_schet1, vidoff,"|"
      print "                                                         |----------------|"
      print " :  I                       |                |"
      print ": ",passon, underlineon, p_myorg.nam, " ", underlineoff, passoff, "             | ", sschetall using " ##########.## ","|"
      print "                                                         `----------------'"
      print " : ",passon, underlineon, strspeak clipped,underlineoff,passoff
      print " :", passon,"    N -", passoff, num using "<<<<<", passon, "i", passoff, schetdat using "dd/mm/yyyy", passon, ",  i ", passoff, spdv using "#####.##", " ."
      #print "           : ", sschet, " ., 0.8% - ", sproc, " ."
      #print "           : ", sschet, " ."
      print ""
      print "i i:                         :"
      print "                                       i  :"
      skip 1 line
      print "============================================================================="
      skip 1 line
      print "                                    .-------. .---------."
      print "                  I N -     |       | | 0402001 |"
      print "                  i `-------' `---------'"
      #print "             ______________________ 200__ . "
      #print "                  ", today using "dd/mm/yyyy", " "
      print "                 :", day(today) using "## ", speakmonth(month(today)) clipped, year(today) using " #### ", ""
      print "                                                         .----------------."
      print "                                                         | 29027304440000 |"
      print "                                             . .----------------."
      print "i : ", passon, underlineon, klientnam, " ", underlineoff, passoff, "       N |",vidon, p_myorg.bank_schet1, vidoff,"|"
      print "                                                         |----------------|"
      print " :  I                       |                |"
      print ": ",passon, underlineon, p_myorg.nam, " ", underlineoff, passoff, "             | ", sschetall using " ##########.## ","|"
      print "                                                         `----------------'"
      print " : ",passon, underlineon, strspeak clipped,underlineoff,passoff
      print " :", passon,"    N -", passoff, num using "<<<<<", passon, "i", passoff, schetdat using "dd/mm/yyyy", passon, ",  i ", passoff, spdv using "#####.##"," ."
      #print "           : ", sschet, " ., 0.8% - ", sproc, " ."
      #print "           : ", sschet, " ."
      print ""
      print "..         :                  i  :"
      skip 1 line
      print "============================================================================="
      skip 1 line
      print "                                    .-------. .---------."
      print "                       N -     |       | | 0402001 |"
      print "                  i `-------' `---------'"
      #print "             ______________________ 200__ . "
      #print "                  ", today using "dd/mm/yyyy", " "
      print "                 :", day(today) using "## ", speakmonth(month(today)) clipped, year(today) using " #### ", ""
      print "i : ", passon, underlineon, klientnam, underlineoff, passoff, "                   "
      print "                                               .----------------------------."
      print "                                               |  N - 030 |",sschetall using " #######.##","   |"
      print "                                               `-------------|              |"
      print "                                                       |      |"
      print "  I             .--------------------------------------------|"
      print "                 |  331865 |", vidon, p_myorg.bank_schet1, vidoff,"|i   |"
      print "                               `--------------------------------------------|"
      print ": ", passon, underlineon, p_myorg.nam, " ",underlineoff, passoff, "| 29027304440000 |              |"
      print "                                                             |              |"
      print "                                                             |              |"
      print "                                                             |--------------|"
      print " :    N -", vidon, num using "<<<<<", vidoff, "               | |         |"
      print "               i ", schetdat using "dd/mm/yyyy", ",   i  ", spdv using "#####.##"," .||         |"
      #print "          : ", sschet, " ., 0.8% - ", sproc," . |--------------|"
      #print "          : ", sschet, " .                          |--------------|"
      print "                                                             ||         |"
      print "                                                             ||         |"
      print "                                                             |--------------|"
      print ":                    :                         |N |         |"
      print "                                                             ||         |"
      print "                                                             `--------------'"
      print betweenstr6,formfeed
end report
